# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-07-15 11:55
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("schedule", "0003_auto_20170523_1144"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="room",
            options={"ordering": ("position",)},
        ),
    ]
