{% extends "orga/settings/base.html" %}
{% load i18n %}

{% block settings_content %}
<div>
    <h2>
        {% translate "Password reset:" %} {{ member.get_display_name }} ({{ member.name }})
    </h2>

    {% translate "Do you really want to reset this user's password? They won't be able to log in until they set a new password. The email will go to: " %} <em>{{ member.email }}</em>.
<div class="submit-group panel">
    <span></span>
    <span>
        <form class="float-right" method="post">{% csrf_token %}
            <a class="btn btn-lg btn-info" href={{ team.orga_urls.base }}>{% translate "Back" %}</a>
            <button class="btn btn-lg btn-danger" type="submit">{% translate "Yes" %}</button>
        </form>
    </span>
</div>
</div>
{% endblock %}
