{% extends "orga/settings/base.html" %}
{% load i18n %}

{% block settings_content %}
<div>
    <h2>
        {% translate "Team" %} {{ quotation_open }}{{ team.name }}{{ quotation_close }}
    </h2>

    {% translate "Do you want to resend the email to:" %} <em>{{ object.email }}</em>
<div class="submit-group panel">
    <span></span>
    <span>
    <form class="float-right" method="post">{% csrf_token %}
        <a class="btn btn-info btn-lg" href={{ team.orga_urls.base }}>{% translate "Back" %}</a>
        <button class="btn btn-danger btn-lg" type="submit">{% translate "Yes" %}</button>
    </form>
    </span>
</div>
</div>
{% endblock %}
