@import "../../common/scss/_variables";
@import "../../vendored/bootstrap/scss/bootstrap";
@import "../../vendored/forkawesome/scss/fork-awesome";

body {
  background: $brand-primary;
}

#wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  flex-direction: column;
  min-height: 100vh;
  z-index: 1000;
}

.logo {
  width: 10rem;
  height: auto;
  margin-bottom: 20px;
}

.card {
  padding: 10px;
  width: 24rem;
}

.hidden {
  display: none;
}
.progress {
  height: 4px;
}
