{% extends "orga/base.html" %}
{% block content %}
<div class="flex-container">
    <div class="flex-content">
        {% block settings_content %}
        {% endblock %}
    </div>
</div>
{% endblock %}
