{% extends "orga/cfp/base.html" %}
{% load bootstrap4 %}
{% load i18n %}

{% block cfp_content %}
<h2>
    {% translate "Send out reminders" %}
</h2>
<div>
  <p>
    {% blocktranslate trimmed %}
    Here you can limit who will receive reminder emails.
    You will be able to review emails before they are sent out.
    {% endblocktranslate %}
  </p>
</div>
<form class="form" method="post">
  {% csrf_token %}
    {% bootstrap_form filter_form layout='event' %}
  <div class="pt-2 submit-group">
    <div></div>
      <button class="btn btn-lg btn-success" type="submit">{% translate "Send" %}</button>
  </div>
</form>
{% endblock %}
