{% extends "orga/event/wizard/base.html" %}
{% load i18n %}

{% block wizard_content %}
<div class="alert alert-info col-md-9 offset-md-3">
    {% translate "The event creation assistant will help you to get started with a new event." %}
</div>
{% endblock %}
